@@ -83,6 +83,7 @@ class FieldTypeEnum(IntEnum):
     STRING = 0
     INT = 1
     STRING_LIST = 2
+    KEY_VALUE_LIST = 3
 
 
 class CompressionTypeEnum(Enum):
@@ -237,7 +238,7 @@ class PkgVerificationTypeEnum(Enum):
 class PkgTypeEnum(Enum):
     """An Enum to distinguish different package types
 
-    The member values represents the name of a possible repod.files.buildinfo.PkgType value
+    The member values represents the name of a possible repod.files.pkginfo.PkgType value
 
     Attributes
     ----------
@@ -245,10 +246,16 @@ class PkgTypeEnum(Enum):
         A default package
     DEBUG: str
         A debug package
+    SOURCE: str
+        A source package
+    SPLIT: str
+        A split package
     """
 
     PKG = "pkg"
     DEBUG = "debug"
+    SOURCE = "src"
+    SPLIT = "split"
 
 
 class RepoFileEnum(IntEnum):
@@ -299,18 +306,6 @@ class SettingsTypeEnum(Enum):
     SYSTEM = "system"
 
 
-def pkg_types_for_pkgtype_regex() -> str:
-    """Return the members of PkgTypeEnum formatted for use in the PKGTYPE regular expression
-
-    Returns
-    -------
-    str
-        The members of PkgTypeEnum formatted as an "or" concatenated string, which matches the values of all members.
-    """
-
-    return r"|".join([type_.value for type_ in PkgTypeEnum])
-
-
 def tar_compression_types_for_filename_regex() -> str:
     """Return the members of CompressionTypeEnum formatted for use in the FILENAME regular expression
 
